pub struct DeviceHandle<P: PhantomDevice> { /* private fields */ }Expand description
Type-safe device handle with phantom device information
This wrapper provides compile-time device type safety for device operations. The phantom type parameter carries device information at the type level.
Examples
ⓘ
use torsh_core::device::{DeviceHandle, PhantomCpu, PhantomCuda};
// CPU device handle
let cpu_handle = DeviceHandle::<PhantomCpu>::new(cpu_device);
// CUDA device handle with index 0
let cuda_handle = DeviceHandle::<PhantomCuda<0>>::new(cuda_device);
// Compile-time device type checking
assert!(cpu_handle.is_cpu());
assert!(cuda_handle.is_gpu());Implementations
Sourceimpl<P: PhantomDevice> DeviceHandle<P>
impl<P: PhantomDevice> DeviceHandle<P>
Sourcepub fn new(device: Box<dyn Device>) -> Result<Self, TorshError>
pub fn new(device: Box<dyn Device>) -> Result<Self, TorshError>
Create a new device handle with phantom type information
Sourcepub unsafe fn new_unchecked(device: Box<dyn Device>) -> Self
pub unsafe fn new_unchecked(device: Box<dyn Device>) -> Self
Create an unchecked device handle (unsafe)
Safety
The caller must ensure that the device type matches the phantom type.
Sourcepub fn device_mut(&mut self) -> &mut dyn Device
pub fn device_mut(&mut self) -> &mut dyn Device
Get the underlying device mutably
Sourcepub fn phantom_device_type() -> DeviceType
pub fn phantom_device_type() -> DeviceType
Get the phantom device type
Sourcepub fn cast<Q: PhantomDevice>(
self,
) -> Result<DeviceHandle<Q>, (Self, TorshError)>
pub fn cast<Q: PhantomDevice>( self, ) -> Result<DeviceHandle<Q>, (Self, TorshError)>
Convert to a different phantom device type (with runtime check)
Sourcepub unsafe fn cast_unchecked<Q: PhantomDevice>(self) -> DeviceHandle<Q>
pub unsafe fn cast_unchecked<Q: PhantomDevice>(self) -> DeviceHandle<Q>
Convert to a different phantom device type (unsafe, no runtime check)
Safety
The caller must ensure that the device type matches the target phantom type.
Sourcepub fn into_device(self) -> Box<dyn Device>
pub fn into_device(self) -> Box<dyn Device>
Extract the underlying device, consuming the handle